diff lisp/reveal.el @ 60487:bf372b4b92e9

(reveal-mode-map): Bind C-a to beginning-of-line.
author Kim F. Storm <storm@cua.dk>
date Mon, 07 Mar 2005 11:12:40 +0000
parents f3c5c717aa02
children 386a445c2ae9 29e773288013
line wrap: on
line diff
--- a/lisp/reveal.el	Mon Mar 07 11:12:31 2005 +0000
+++ b/lisp/reveal.el	Mon Mar 07 11:12:40 2005 +0000
@@ -161,8 +161,9 @@
 
 (defvar reveal-mode-map
   (let ((map (make-sparse-keymap)))
-    ;; Override the default move-end-of-line which skips valuable
-    ;; invisible text.
+    ;; Override the default move-beginning-of-line and move-end-of-line
+    ;; which skips valuable invisible text.
+    (define-key map [?\C-a] 'beginning-of-line)
     (define-key map [?\C-e] 'end-of-line)
     map))